package com.io.yutian.auchestshop.database;

import com.io.yutian.auchestshop.AuChestShop;
import com.io.yutian.aulib.sql.SQLHelper;
import com.io.yutian.aulib.sql.api.SQLManager;
import com.io.yutian.aulib.sql.api.SQLQuery;
import com.io.yutian.aulib.sql.api.enums.IndexType;
import com.io.yutian.aulib.sql.manager.SQLManagerImpl;
import com.io.yutian.aulib.sql.util.DatabaseDriverType;
import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;

import java.io.File;
import java.io.IOException;
import java.sql.ResultSet;
import java.util.UUID;

public class SQLIO {

    private SQLManager sqlManager;

    public void init() throws IOException {
        HikariConfig config = new HikariConfig();
        config.setDriverClassName(DatabaseDriverType.H2.getDriverClassName());
        config.setJdbcUrl("jdbc:h2:"+new File(AuChestShop.inst().getDataFolder(), "shops").getCanonicalFile().getAbsolutePath() + ";MODE=MYSQL");
        sqlManager = new SQLManagerImpl(new HikariDataSource(config), "AuChestShop-Hikari-SQLManager");
        sqlManager.executeSQL("SET MODE=MYSQL;");
        sqlManager.setExecutorPool(SQLExecutor.HIKARICP_EXECUTOR);

        createTables();
    }

    private void createTables() {
        sqlManager.createTable("shops")
                .addColumn("uuid", "VARCHAR(32) NOT NULL")
                .addColumn("owner", "VARCHAR(32) NOT NULL")
                .addColumn("item", "TEXT NOT NULL")
                .addColumn("type", "INT NOT NULL DEFAULT 0")
                .addColumn("price", "DECIMAL(32,2) NOT NULL")
                .addColumn("unlimited", "BIT NOT NULL DEFAULT 0")
                .addColumn("log", "TEXT NOT NULL")
                .addColumn("create_time", "LONG NOT NULL")
                .setIndex("uuid", IndexType.UNIQUE_KEY)
                .build().execute(null);
    }

    private void query(UUID uuid) {
        try (SQLQuery query = sqlManager.createQuery()
                .inTable("shops")
                .selectColumns("uuid", "name", "item", "type", "price", "unlimited", "create_time")
                .addCondition("uuid", uuid.toString())
                .build().execute(null)) {
            try (ResultSet resultSet = query.getResultSet()) {
                while (resultSet.next()) {
                    String name = resultSet.getString("name");

                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void close() {
        if (sqlManager == null) {
            return;
        }
        SQLHelper.shutdownManager(sqlManager);
    }

}
